@@ -1,12 +1,13 @@
 try:
     from pathlib import Path
+
     Path().expanduser()
-except (ImportError,AttributeError):
-    raise ValueError('Please use python 3.')
+except (ImportError, AttributeError):
+    raise ValueError("Please use python 3.")
 
 from ._version import get_versions
 
-from .ISRSpectrum import Specinit
+from .ISRSpectrum import Specinit, ioncheck, getionmass
 
 from .mathutils import *
 
